@@ -46,9 +46,13 @@
 #include <limits>
 #include "http.h"
 
-#ifdef _MSC_VER
-#define stat64 _stat64
+#ifdef WIN32
+#define stat_os _stat64
+#elif defined(__APPLE__)
+#define stat_os stat
+#include "dirent.h"
 #else
+#define stat_os stat64
 #include "dirent.h"
 #endif
 
@@ -129,10 +133,10 @@ public:
 	FSFlat() { m_ext = ""; }
 	int get_file_timesample(const string &filename, uint64_t *ptime) override
 	{
-		struct stat64 st;
-		if (stat64(filename.c_str() + 1, &st))
+		struct stat_os st;
+		if (stat_os(filename.c_str() + 1, &st))
 		{
-			set_last_err_string("stat64 failure");
+			set_last_err_string("stat_os failure");
 			return -1;
 		}
 
@@ -143,16 +147,16 @@ public:
 
 	bool exist(const string &backfile, const string &filename) override
 	{
-		struct stat64 st;
-		return stat64(backfile.c_str() + 1, &st) == 0 && ((st.st_mode & S_IFDIR) == 0);
+		struct stat_os st;
+		return stat_os(backfile.c_str() + 1, &st) == 0 && ((st.st_mode & S_IFDIR) == 0);
 	}
 
 	int load(const string &backfile, const string &filename, shared_ptr<FileBuffer> p, bool async) override
 	{
-		struct stat64 st;
-		if (stat64(backfile.c_str() + 1, &st))
+		struct stat_os st;
+		if (stat_os(backfile.c_str() + 1, &st))
 		{
-			set_last_err_string("stat64 failure");
+			set_last_err_string("stat_os failure");
 			return -1;
 		}
 		p->unmapfile();
@@ -170,9 +174,9 @@ public:
 
 	int for_each_ls(uuu_ls_file fn, const string &backfile, const string &filename, void *p) override
 	{
-		struct stat64 st;
+		struct stat_os st;
 
-		if(stat64(backfile.c_str() + 1, &st))
+		if(stat_os(backfile.c_str() + 1, &st))
 		{
 			return -1;
 		}
@@ -1347,6 +1351,7 @@ int FileBuffer::ref_other_buffer(shared_ptr<FileBuffer> p, size_t offset, size_t
 {
 	m_pDatabuffer = p->data() + offset;
 	m_DataSize = m_MemSize = size;
+	m_avaible_size = m_DataSize;
 	m_allocate_way = ALLOCATION_WAYS::REF;
 	m_ref = p;
 	return 0;
@@ -1368,7 +1373,7 @@ int FileBuffer::request_data(size_t sz)
 {
 	std::unique_lock<std::mutex> lck(m_requext_cv_mutex);
 
-	while(!this->m_dataflags & FILEBUFFER_FLAG_KNOWN_SIZE_BIT)
+	while(!(this->m_dataflags & FILEBUFFER_FLAG_KNOWN_SIZE_BIT))
 		m_request_cv.wait(lck);
 
 	if (IsLoaded())
@@ -1403,15 +1408,29 @@ int FileBuffer::request_data(size_t sz)
 	return 0;
 }
 
-int FileBuffer::request_data(vector<uint8_t> &data, size_t offset, size_t sz)
+int FileBuffer::request_data(std::vector<uint8_t> &data, size_t offset, size_t sz)
+{
+	int64_t ret;
+	ret = request_data(data.data(), offset, sz);
+	if (ret < 0)
+	{
+		data.clear();
+		return -1;
+	}
+
+	data.resize(ret);
+	return 0;
+}
+
+int64_t FileBuffer::request_data(void *data, size_t offset, size_t sz)
 {
 	bool needlock = false;
+	int ret = 0;
 
 	if (IsLoaded())
 	{
 		if (offset >= this->size())
 		{
-			data.clear();
 			set_last_err_string("request offset execeed memory size");
 			return -1;
 		}
@@ -1433,7 +1452,6 @@ int FileBuffer::request_data(vector<uint8_t> &data, size_t offset, size_t sz)
 		{
 			if (offset > m_avaible_size)
 			{
-				data.clear();
 				set_last_err_string("request offset execeed memory size");
 				return -1;
 			}
@@ -1445,15 +1463,51 @@ int FileBuffer::request_data(vector<uint8_t> &data, size_t offset, size_t sz)
 	if (offset + size >= m_avaible_size)
 		size = m_avaible_size - offset;
 
-	data.resize(size);
-
 	if (needlock) m_data_mutex.lock();
 
-	memcpy(data.data(), this->data() + offset, size);
-
+	if (this->data())
+	{
+		memcpy(data, this->data() + offset, size);
+		ret = size;
+	}
+	else
+	{
+		set_last_err_string("Out of memory");
+		ret = ERR_OUT_MEMORY;
+	}
 	if (needlock) m_data_mutex.unlock();
 
-	return 0;
+	return ret;
+}
+
+std::shared_ptr<FileBuffer> FileBuffer::request_data(size_t offset, size_t sz)
+{
+	shared_ptr<FileBuffer> p(new FileBuffer);
+
+	if (IsLoaded())
+	{
+		if (offset >= this->size())
+		{
+			set_last_err_string("request offset bigger than file size");
+			return nullptr;
+		}
+
+		size_t size = sz;
+		if (offset + sz > this->size())
+			size = this->size() - offset;
+		p->ref_other_buffer(shared_from_this(), offset, size);
+		return p;
+	}
+
+	p->reserve(sz);
+	int64_t ret = request_data(p->m_pDatabuffer, offset, sz);
+	if (ret < 0)
+		return nullptr;
+
+	p->resize(ret);
+	p->m_avaible_size = ret;
+	atomic_fetch_or(&p->m_dataflags, FILEBUFFER_FLAG_LOADED);
+	return p;
 }
 
 int FileBuffer::reserve(size_t sz)
@@ -1477,6 +1531,16 @@ int FileBuffer::reserve(size_t sz)
 
 int FileBuffer::resize(size_t sz)
 {
+	if (this->m_allocate_way == ALLOCATION_WAYS::REF)
+	{
+		if (sz > m_DataSize)
+		{
+			assert(true);
+			return 0;
+		}
+		m_DataSize = sz;
+		return m_DataSize;
+	}
 	int ret = reserve(sz);
 
 	m_DataSize = sz;
