@@ -67,14 +67,17 @@ Config::Config()
 	emplace_back(ConfigItem{"SDP:", "MX8MQ",   "MX8MQ", NXP_VID, 0x012B});
 	emplace_back(ConfigItem{"SDPU:", "SPL",    "SPL",  0x0525, 0xB4A4, 0,      0x04FF});
 	emplace_back(ConfigItem{"SDPV:", "SPL1",   "SPL",  0x0525, 0xB4A4, 0x0500, 0x9998});
+	emplace_back(ConfigItem{"SDPV:", "SPL1",   "SPL",  NXP_VID, 0x0151, 0x0500, 0x9998});
 	emplace_back(ConfigItem{"SDPU:", "SPL",    "SPL",  0x0525, 0xB4A4, 0x9999, 0x9999}); /*old i.MX8 MQEVk use bcd 9999*/
 	emplace_back(ConfigItem{"SDPU:", "SPL",    "SPL",  BD_VID, 0x1001, 0,      0x04FF});
 	emplace_back(ConfigItem{"SDPV:", "SPL1",   "SPL",  BD_VID, 0x1001, 0x0500, 0x9998});
 	emplace_back(ConfigItem{"FBK:", nullptr, nullptr, 0x066F, 0x9AFE});
 	emplace_back(ConfigItem{"FBK:", nullptr, nullptr, 0x066F, 0x9BFF});
+	emplace_back(ConfigItem{"FBK:", nullptr, nullptr, NXP_VID, 0x0153});
 	emplace_back(ConfigItem{"FB:", nullptr, nullptr,  0x0525, 0xA4A5});
 	emplace_back(ConfigItem{"FB:", nullptr, nullptr,  0x18D1, 0x0D02});
 	emplace_back(ConfigItem{"FB:", nullptr, nullptr,  BD_VID, 0x0001});
+	emplace_back(ConfigItem{"FB:", nullptr, nullptr,  NXP_VID, 0x0152});
 }
 
 int uuu_for_each_cfg(uuu_show_cfg fn, void *p)
