@@ -128,9 +128,11 @@ int uuu_wait_uuu_finish(int deamon, int dry);
 int uuu_add_usbpath_filter(const char *path);
 
 /*Set timeout wait for known devices appeared*/
-int uuu_set_wait_timeout(int second);
+int uuu_set_wait_timeout(int timeout_in_seconds);
+/*Set timeout wait for next devices appeared, e.g. FB -> FBK*/
+int uuu_set_wait_next_timeout(int timeout_in_seconds);
 /*Set usb device polling period */
-void uuu_set_poll_period(int msecond);
+void uuu_set_poll_period(int period_in_milliseconds);
 /*
  * bit 0:15 for libusb
  * bit 16:31 for uuu
