@@ -132,17 +132,20 @@ void print_help(bool detail = false)
 		"                example: SDPS: boot -f flash.bin\n"
 		"    -d          Daemon mode, wait for forever.\n"
 		"    -v -V       verbose mode, -V enable libusb error\\warning info\n"
-		"    -dry	 Dry run mode, check if script or cmd correct \n"
+		"    -dry        Dry run mode, check if script or cmd correct \n"
 		"    -m          USBPATH Only monitor these paths.\n"
 		"                    -m 1:2 -m 1:3\n\n"
 		"    -t          Timeout second for wait known usb device appeared\n"
+		"    -T          Timeout second for wait next known usb device appeared at stage switch\n"
 		"    -e          set environment variable key=value\n"
 		"    -pp         usb polling period in milliseconds\n"
 		"uuu -s          Enter shell mode. uuu.inputlog record all input commands\n"
 		"                you can use \"uuu uuu.inputlog\" next time to run all commands\n\n"
 		"uuu -udev       linux: show udev rule to avoid sudo each time \n"
 		"uuu -lsusb      List connected know devices\n"
-		"uuu -h -H       show help, -H means detail helps\n\n";
+		"uuu -IgSerNum   Set windows registry to ignore USB serial number for known uuu devices\n"
+		"uuu -h          show general help\n"
+		"uuu -H          show general help and detailed help for commands\n\n";
 	printf("%s", help);
 	printf("uuu [-d -m -v] -b[run] ");
 	g_BuildScripts.ShowCmds();
@@ -781,6 +784,37 @@ void print_lsusb()
 	uuu_for_each_devices(print_usb_device, NULL);
 }
 
+#ifdef WIN32
+int ignore_serial_number(const char *pro, const char *chip, const char */*comp*/, uint16_t vid, uint16_t pid, uint16_t /*bcdlow*/, uint16_t /*bcdhigh*/, void */*p*/)
+{
+	printf("\t %s\t %s\t 0x%04X\t0x%04X\n", chip, pro, vid, pid);
+
+	char sub[128];
+	snprintf(sub, 128, "IgnoreHWSerNum%04x%04x", vid, pid);
+	const BYTE value = 1;
+
+	LSTATUS ret = RegSetKeyValueA(HKEY_LOCAL_MACHINE,
+								  "SYSTEM\\CurrentControlSet\\Control\\UsbFlags",
+									sub, REG_BINARY, &value, 1);
+	if(ret == ERROR_SUCCESS)
+		return 0;
+
+	printf("Set key failure, try run as administrator permission\n");
+	return -1;
+}
+#endif
+
+int set_ignore_serial_number()
+{
+#ifndef WIN32
+	printf("Only windows system need set ignore serial number registry");
+	return -1;
+#else
+	printf("Set window registry to ignore usb hardware serial number for known uuu device:\n");
+	return uuu_for_each_cfg(ignore_serial_number, NULL);
+#endif
+}
+
 int main(int argc, char **argv)
 {
 	if (auto_complete(argc, argv) == 0)
@@ -794,6 +828,25 @@ int main(int argc, char **argv)
 			print_udev();
 			return 0;
 		}
+		if (s == "-bshow")
+		{
+			if (2 == argc || g_BuildScripts.find(argv[2]) == g_BuildScripts.end())
+			{
+				fprintf(stderr, "Error, must be have script name: ");
+				g_BuildScripts.ShowCmds(stderr);
+				fprintf(stderr,"\n");
+				return -1;
+			}
+			else
+			{
+				string str = g_BuildScripts[argv[2]].m_text;
+				while (str.size() > 0 && (str[0] == '\n' || str[0] == ' '))
+					str = str.erase(0,1);
+
+				printf("%s", str.c_str());
+				return 0;
+			}
+		}
 	}
 
 	AutoCursor a;
@@ -868,6 +921,11 @@ int main(int argc, char **argv)
 				i++;
 				uuu_set_wait_timeout(atoll(argv[i]));
 			}
+			else if (s == "-T")
+			{
+				i++;
+				uuu_set_wait_next_timeout(atoll(argv[i]));
+			}
 			else if (s == "-pp")
 			{
 				i++;
@@ -878,6 +936,10 @@ int main(int argc, char **argv)
 				print_lsusb();
 				return 0;
 			}
+			else if (s == "-IgSerNum")
+			{
+				return set_ignore_serial_number();
+			}
 			else if (s == "-e")
 			{
 #ifndef WIN32
@@ -886,7 +948,7 @@ int main(int argc, char **argv)
 				i++;
 				if (_putenv(argv[i]))
 				{
-					printf("error, failed to set '%s', environment parameter must have the from key=value\n", argv[i]);
+					printf("error, failed to set '%s', environment parameter must have the form key=value\n", argv[i]);
 					return -1;
 				}
 			}
@@ -914,9 +976,7 @@ int main(int argc, char **argv)
 
 				// if script name is not build-in, try to look for a file
 				if (g_BuildScripts.find(argv[i + 1]) == g_BuildScripts.end()) {
-					BuildCmd tmpCmd;
-					string tmpCmdFileName = argv[i + 1];
-					tmpCmd.m_cmd = tmpCmdFileName.c_str();
+					const string tmpCmdFileName{argv[i + 1]};
 
 					std::ifstream t(tmpCmdFileName);
 					std::string fileContents((std::istreambuf_iterator<char>(t)),
@@ -927,12 +987,13 @@ int main(int argc, char **argv)
 						return -1;
 					}
 
-					tmpCmd.m_buildcmd = fileContents.c_str();
+					BuiltInScriptRawData tmpCmd{
+						tmpCmdFileName.c_str(),
+						fileContents.c_str(),
+						"Script loaded from file"
+					};
 
-					tmpCmd.m_desc = "Script loaded from file";
-
-					BuildInScript tmpBuildInScript(&tmpCmd);
-					g_BuildScripts[tmpCmdFileName] = tmpBuildInScript;
+					g_BuildScripts.emplace(tmpCmdFileName, &tmpCmd);
 
 					cmd_script = g_BuildScripts[tmpCmdFileName].replace_script_args(args);
 				}
@@ -941,21 +1002,6 @@ int main(int argc, char **argv)
 				}
 				break;
 			}
-			else if (s == "-bshow")
-			{
-				if (i + 1 == argc || g_BuildScripts.find(argv[i+1]) == g_BuildScripts.end())
-				{
-					printf("error, must be have script name: ");
-					g_BuildScripts.ShowCmds();
-					printf("\n");
-					return -1;
-				}
-				else
-				{
-					printf("%s", g_BuildScripts[argv[i + 1]].m_script.c_str());
-					return 0;
-				}
-			}
 			else
 			{
 				cout << "Unknown option: " << s.c_str();
@@ -1056,9 +1102,9 @@ int main(int argc, char **argv)
 
 	if (ret)
 	{
-		runshell(shell);
-
-		cout << g_vt_red << "\nError: " << g_vt_default <<  uuu_get_last_err_string();
+		ret = runshell(shell);
+		if(ret)
+			cout << g_vt_red << "\nError: " << g_vt_default <<  uuu_get_last_err_string();
 		return ret;
 	}
 
